import math
def c_2(angle, hyp):
        angle_a = float(angle)
        hyp = float(hyp)
        while angle_a > 90:
            angle_a = angle_a - 90
        c_1 = round(math.sin(math.radians(angle_a)) * hyp, 4)
        return c_1

def c_1(angle, hyp):
        angle_a = float(angle)
        hyp = float(hyp)
        while angle_a > 90:
            angle_a = angle_a - 90
        c_2 = round(math.cos(math.radians(angle_a)) * hyp, 4)
        return c_2

def area(angle, hyp):
        angle_a = float(angle)
        hyp = float(hyp)
        while angle_a > 90:
            angle_a = angle_a - 90
        c_1 = round(math.sin(math.radians(angle_a)) * hyp, 4)
        c_2 = round(math.cos(math.radians(angle_a)) * hyp, 4)
        area = round(c_1 * c_2 * 0.5, 4)
        return area


from setuptools import setup, find_packages

classifiers = [
    #'Development status :: 5 - Production/Stable',
    #'Intended Audience :: Developers',
    #'Operating system :: Microsoft :: Windows :: Windows 10',
    #'License :: OSI Approved :: MIT License',
    #'Programming Language :: Python :: 3'
]

setup(
    name='SimpleCalc2',
    version='0.0.1',
    description='A very basic calculator for algebra problems.',
    Long_description=open('README.txt').read() + '\n\n' + open('CHANGELOG.txt').read(),
    url='',
    author='Leonardo Ricci Mingani',
    author_email='leonardo.riccimingani@gmail.com',
    License='MIT',
    classifiers=classifiers,
    keyword='calculator',
    pakages=find_packages(),
    install_requires=['']
)